@@ -4,6 +4,7 @@ import logging
 
 import telepathy
 
+import tp
 import util.coroutines as coroutines
 import gtk_toolbox
 
@@ -11,7 +12,7 @@ import gtk_toolbox
 _moduleLogger = logging.getLogger("channel.text")
 
 
-class TextChannel(telepathy.server.ChannelTypeText):
+class TextChannel(tp.ChannelTypeText):
 	"""
 	Look into implementing ChannelInterfaceMessages for rich text formatting
 	"""
@@ -20,32 +21,12 @@ class TextChannel(telepathy.server.ChannelTypeText):
 		self.__manager = manager
 		self.__props = props
 
-		try:
-			# HACK Older python-telepathy way
-			telepathy.server.ChannelTypeText.__init__(self, connection, contactHandle)
-			self._requested = props[telepathy.interfaces.CHANNEL_INTERFACE + '.Requested']
-			self._implement_property_get(
-				telepathy.interfaces.CHANNEL_INTERFACE,
-				{"Requested": lambda: self._requested}
-			)
-		except TypeError:
-			# HACK Newer python-telepathy way
-			telepathy.server.ChannelTypeText.__init__(self, connection, manager, props)
+		tp.ChannelTypeText.__init__(self, connection, manager, props)
 		self.__nextRecievedId = 0
 		self.__lastMessageTimestamp = datetime.datetime(1, 1, 1)
 
 		self.__otherHandle = contactHandle
 
-		# HACK Older python-telepathy doesn't provide this
-		self._immutable_properties = {
-			'ChannelType': telepathy.server.interfaces.CHANNEL_INTERFACE,
-			'TargetHandle': telepathy.server.interfaces.CHANNEL_INTERFACE,
-			'Interfaces': telepathy.server.interfaces.CHANNEL_INTERFACE,
-			'TargetHandleType': telepathy.server.interfaces.CHANNEL_INTERFACE,
-			'TargetID': telepathy.server.interfaces.CHANNEL_INTERFACE,
-			'Requested': telepathy.server.interfaces.CHANNEL_INTERFACE
-		}
-
 		self.__callback = coroutines.func_sink(
 			coroutines.expand_positional(
 				self._on_conversations_updated
@@ -73,14 +54,6 @@ class TextChannel(telepathy.server.ChannelTypeText):
 		else:
 			self._report_conversation(mergedConversations)
 
-	def get_props(self):
-		# HACK Older python-telepathy doesn't provide this
-		props = dict()
-		for prop, iface in self._immutable_properties.items():
-			props[iface + '.' + prop] = \
-				self._prop_getters[iface][prop]()
-		return props
-
 	@gtk_toolbox.log_exception(_moduleLogger)
 	def Send(self, messageType, text):
 		if messageType != telepathy.CHANNEL_TEXT_MESSAGE_TYPE_NORMAL:
@@ -105,10 +78,7 @@ class TextChannel(telepathy.server.ChannelTypeText):
 		)
 		self.__callback = None
 
-		telepathy.server.ChannelTypeText.Close(self)
-		if self.__manager.channel_exists(self.__props):
-			# HACK Older python-telepathy requires doing this manually
-			self.__manager.remove_channel(self)
+		tp.ChannelTypeText.Close(self)
 		self.remove_from_connection()
 
 	@property
